summaryrefslogtreecommitdiff
path: root/tests/warn
diff options
context:
space:
mode:
authorDieter Verfaillie <dieterv@optionexplicit.be>2013-05-28 17:20:49 +0200
committerDieter Verfaillie <dieterv@optionexplicit.be>2013-10-08 20:54:59 +0200
commitcc96177ec877153e7e5e55e6af270829da546015 (patch)
treec316058a23302adf9e63b3227d92853af692096c /tests/warn
parent4d1972cedd20bb51b8c67ec030339d5d4dce12a9 (diff)
downloadgobject-introspection-cc96177ec877153e7e5e55e6af270829da546015.tar.gz
giscanner: give pointer to original comment block...
...when complaining about multiple comment blocks documenting the same identifier.
Diffstat (limited to 'tests/warn')
-rw-r--r--tests/warn/annotationparser.h19
1 files changed, 14 insertions, 5 deletions
diff --git a/tests/warn/annotationparser.h b/tests/warn/annotationparser.h
index 87b632f4..db04b5a0 100644
--- a/tests/warn/annotationparser.h
+++ b/tests/warn/annotationparser.h
@@ -1,18 +1,27 @@
#include "common.h"
/**
- * test_symbol_twice_documented:
+ * test_symbol_thrice_documented:
*
* Documenting the same thing multiple times can lead to subtle bugs.
* For example, one comment block might have correct annotations...
**/
-void test_symbol_twice_documented();
+void test_symbol_thrice_documented();
/**
- * test_symbol_twice_documented:
+ * test_symbol_thrice_documented:
*
* ...and a different comment block (out of sync with the above) might have
- * no annotations at all. The last comment block seen by the parser "wins".
+ * no annotations at all. The last comment block seen by the parser "wins"...
**/
-// EXPECT:12: Warning: Test: multiple comment blocks documenting 'test_symbol_twice_documented:' identifier.
+// EXPECT:12: Warning: Test: multiple comment blocks documenting 'test_symbol_thrice_documented:' identifier (already seen at annotationparser.h:4).
+
+
+/**
+ * test_symbol_thrice_documented:
+ *
+ * ...and yet another one.
+ **/
+
+// EXPECT:22: Warning: Test: multiple comment blocks documenting 'test_symbol_thrice_documented:' identifier (already seen at annotationparser.h:12).